spotlight

package
v0.2.27 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 6, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Overview

Package spotlight syncs worktree changes to the main repo for testing.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsActive

func IsActive(worktreePath string) bool

IsActive checks if spotlight mode is currently active for the worktree.

func Start

func Start(worktreePath, mainRepoDir string) (string, error)

Start enables spotlight mode and performs initial sync.

func StateFile

func StateFile(worktreePath string) string

StateFile returns the path to the spotlight state file in the worktree.

func Status

func Status(worktreePath, mainRepoDir string) (string, error)

Status returns the current spotlight status.

func Stop

func Stop(worktreePath, mainRepoDir string) (string, error)

Stop disables spotlight mode and restores the main repo.

func Sync

func Sync(worktreePath, mainRepoDir string) (string, error)

Sync syncs git-tracked files from worktree to main repo. It compares files between the worktree and main repo, copying any that differ. Also handles file deletions by detecting files that exist in main but not in worktree.

Types

This section is empty.

Jump to